from .diskInfo import diskInfo
from .installPythonModule import installPythonModule
from .internetInfo import internetInfo
from .killChrome import killChrome
from .listDrives import listDrives
from .listUsers import listUsers
from .netSupport import killNetSupport
from .performanceMonitor import performanceMonitor
from .systemInfo import systemInfo
from .taskManager import taskManager
from .treeDrives import treeDrives



import os

from setuptools import setup, find_packages


readme = os.path.join(os.path.dirname(__file__), "README.rst")

VERSION = '0.0.5'
DESCRIPTION = 'Systems are supposed to be tested'

setup(
    name="GSAToolKit",
    version=VERSION,
    author="Joe",
    author_email="alex.riddell88@gmail.com",
    description=DESCRIPTION,
    long_description=open(readme).read(),
    packages=find_packages(),
    install_requires=[],

    keywords=['python', 'GSA'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ]
)



import psutil
import os


def killNetSupport():
    apps = ["StudentUI.exe", "NSSilence.exe", "Runplugin64.exe", "runplugin.exe"]
    for app in apps:
        for proc in psutil.process_iter():
            try:
                if app.lower() in proc.name().lower():
                    os.system("taskkill /F /IM {}".format(app))
            except (psutil.NoSuchProcess, psutil.AccessDenied, psutil.ZombieProcess):
                pass
        print("{} is not running".format(app))
